@@ -7,7 +7,7 @@ def command(template):
         def handle(*args):
             data = shlex.split(args[-1])
             if fields[0] == data[0]: 
-                func(*args, **dict(zip(fields[1:], data[1:])))
+                func(*args, **dict(list(zip(fields[1:], data[1:]))))
         return handle
     return shell
 
