@@ -11,8 +11,7 @@ def PLUGIN_SCHEME(server):
 
 """
 
-from untwisted.plugins.irc import send_cmd, send_msg
-from untwisted.network import xmap
+from quickirc import send_cmd, send_msg
 from ameliabot.cmd import regcmd
 import time
 
@@ -25,7 +24,7 @@ class AntiSpam(object):
             cmd = 'kick {chan} {nick} :Amelia rocks!'
             cmd = 'chanserv akick {chan} add *!*@{host} : get out!
         """
-        xmap(server, 'CMSG', self.watcher)
+        server.add_map('CMSG', self.watcher)
         self.data    = {}
         self.n_lines = n_lines
         self.n_secs  = n_secs
@@ -55,3 +54,4 @@ install = AntiSpam
 
 
 
+
