@@ -12,9 +12,7 @@ Description: List all files that exist in a given folder that was shared.
 
 """
 
-import libpad
-from untwisted.network import xmap
-from untwisted.plugins.irc import send_msg
+from quickirc import send_msg
 from ameliabot.cmd import command
 import os
 
@@ -24,20 +22,12 @@ class BookList(object):
         """
 
         self.folder = folder
-        xmap(server, 'CMSG', self.list_folder)
+        server.add_map('CMSG', self.list_folder)
     
     @command('@dcc-list')
     def list_folder(self, server, nick, user, host, target, msg):
         """
         """
         content = '\n'.join(os.listdir(self.folder))
-    
-        url, _ = libpad.sandbox(content, '') 
-        send_msg(server, target, url)
-        
-
-
-
-
-
-
+        send_msg(server, target, content)
+        
\ No newline at end of file
