@@ -19,22 +19,20 @@ Example
 
 import wolframalpha
 
-from untwisted.plugins.irc import send_msg
-from untwisted.network import xmap
+from quickirc import send_msg
 from ameliabot.cmd import regcmd
 from ameliabot.tools import send_lines
 
 class Calculate(object):
     def __init__(self, server, appid):
         self.client = wolframalpha.Client(appid)
-        xmap(server, 'CMSG', self.calculate)
+        server.add_map('CMSG', self.calculate)
     
     @regcmd('@calc (?P<exp>.+)$')
     def calculate(self, server, nick, user, host, target, msg, exp):
         for pod in self.client.query(exp):
             if getattr(pod, 'text', None):
-                send_lines(server, target,
-                    pod.text.encode('utf-8'))
+                send_lines(server, target, pod.text)
     
 install = Calculate
 
@@ -47,3 +45,5 @@ install = Calculate
 
 
 
+
+
