@@ -12,20 +12,20 @@ that are sent to the bot it will be saved in directory that was chosen.
 
 """
 
-from untwisted.plugins.irc import *
+from quickirc import send_msg, DccClient
 from os.path import isfile, join
-from untwisted.network import xmap
-from untwisted.iostd import CLOSE, CONNECT_ERR
+from untwisted.event import CLOSE, CONNECT_ERR, DONE
 from untwisted.iputils import long_to_ip
 
 class Get(object):
     def __init__(self, server, folder):
         self.folder = folder
-        xmap(server, 'DCC SEND', self.dcc_get)
+        server.add_map('DCC SEND', self.dcc_get)
 
-    def dcc_get(self, server, (nick, user, host, 
-                        target, msg), filename, address, port, size):
+    def dcc_get(self, server, xxx_todo_changeme, filename, address, port, size):
     
+        (nick, user, host, 
+                        target, msg) = xxx_todo_changeme
         path = join(self.folder, filename)
 
         if isfile(path):      
@@ -39,9 +39,9 @@ class Get(object):
                 send_msg(server, nick, msg)
                 fd.close()
     
-            xmap(dccclient, DONE, is_done, 'Done.')
-            xmap(dccclient, CLOSE, lambda dccclient, spin, err: is_done(spin, 'Failed.'))
-            xmap(dccclient, CONNECT_ERR, lambda dccclient, spin, err: is_done("It couldn't connect."))
+            dccclient.add_map(DONE, is_done, 'Done.')
+            dccclient.add_map(CLOSE, lambda dccclient, ssock, err: is_done(ssock, 'Failed.'))
+            dccclient.add_map(CONNECT_ERR, lambda dccclient, ssock, err: is_done("It couldn't connect."))
     
     
 install = Get
@@ -52,3 +52,4 @@ install = Get
 
 
 
+
