@@ -6,11 +6,10 @@ This plugin show an welcome message whenever an user joins a channel where the b
 
 """
 
-from untwisted.plugins.irc import send_msg
-from untwisted.network import xmap
+from quickirc import send_msg
 
 def install(server):
-    xmap(server, 'JOIN', send_welcome)
+    server.add_map('JOIN', send_welcome)
 
 def send_welcome(server, nick, user, host, channel):
         send_msg(server, channel, 'Welcome to our relaxed place !')
@@ -23,3 +22,4 @@ def send_welcome(server, nick, user, host, channel):
 
 
 
+
