@@ -13,8 +13,7 @@ Description: Shows the player's rating on lichess.org.
 """
 
 import requests
-from untwisted.plugins.irc import send_msg
-from untwisted.network import xmap
+from quickirc import send_msg
 from ameliabot.cmd import command
 
 def getPlayerInfo(player):
@@ -31,7 +30,7 @@ def ircOutput(playerinfo):
 
 class Lichess:
 	def __init__(self,server):
-		xmap(server,'CMSG',self.getinfo)
+		server.add_map('CMSG',self.getinfo)
 
 	@command('@lichess player')
 	def getinfo(self, server, nick, user, host, target, msg, player):
@@ -39,3 +38,4 @@ class Lichess:
 		send_msg(server,target,str(ircOutput(result)))
 
 install = Lichess
+
