@@ -15,23 +15,22 @@ Description: Remove the pipe from chan_x to chan_y.
 
 """
 
-from untwisted.network import xmap
-from untwisted.plugins.irc import send_msg
+from quickirc import send_msg
 from ameliabot.cmd import command
 
 mapping = dict()
 
 def install(server):
-    xmap(server, 'CMSG', pipe_add)
-    xmap(server, 'CMSG', pipe_rm)
-    xmap(server, 'CMSG', pipe_chan)
+    server.add_map('CMSG', pipe_add)
+    server.add_map('CMSG', pipe_rm)
+    server.add_map('CMSG', pipe_chan)
 
 @command('@pipe-add chan_x chan_y')
 def pipe_add(server, nick, user, host, target, 
                msg, chan_x, chan_y):
 
     chan_x, chan_y = chan_x.upper(), chan_y.upper()
-    if not mapping.has_key((server, chan_x)):
+    if (server, chan_x) not in mapping:
         mapping[(server, chan_x)] = list()
     mapping[(server, chan_x)].append(chan_y)
 
@@ -59,3 +58,4 @@ def pipe_chan(server, nick, user, host, target, msg,):
 
 
 
+
