@@ -1,21 +1,20 @@
 """
 """
 
-from untwisted.network import xmap
-from random import *
+from random import choice
 from re import split
 from os.path import dirname, join
-from untwisted.plugins.irc import send_msg
+from quickirc import send_msg
 from ameliabot.cmd import command
 
 class Quote(object):
     def __init__(self, server):
-        fd   = open(join(dirname(__file__), 'quote_database'), 'r')
-        data = fd.read()
+        fd   = open(join(dirname(__file__), 'quote_database'), 'rb')
+        data = fd.read().decode('utf8', 'ignore')
         fd.close()
         self.data = split('\n+', data)
         
-        xmap(server, 'CMSG', self.send_quote)
+        server.add_map('CMSG', self.send_quote)
 
     @command('@quote')
     def send_quote(self, server, nick, user, host, target, msg):    
@@ -31,3 +30,5 @@ install = Quote
 
 
 
+
+
