@@ -6,9 +6,8 @@ Used to extract url titles from links.
 
 """
 
-from untwisted.plugins.irc import send_msg
+from quickirc import send_msg
 from re import search, compile, sub
-from untwisted.network import xmap
 import requests
 from ehp import *
 
@@ -17,7 +16,7 @@ REG_LINK  = compile(STR_LINK)
 
 class UrlTitle(object):
     def __init__(self, server):
-        xmap(server, 'CMSG', self.check)
+        server.add_map('CMSG', self.check)
     
     def check(self, server, nick, user, host, target, msg):
         struct = search(REG_LINK, msg)
@@ -25,7 +24,7 @@ class UrlTitle(object):
             return
         req   = requests.get(struct.group('address'))
         html  = Html()
-        dom   = html.feed(req.text.encode(req.encoding))
+        dom   = html.feed(req.text)
         title = dom.fst('title').text()
         send_msg(server, target, title)
 
@@ -35,3 +34,5 @@ install = UrlTitle
 
 
 
+
+
