@@ -1,10 +1,10 @@
-from untwisted.plugins.irc import send_msg
+from quickirc import send_msg
 from untwisted.timer import Sched, CancelCall
 from re import escape
 
 def consume(seq):
     try:
-        seq.next()
+        next(seq)
     except StopIteration:
         raise CancelCall
 
@@ -17,3 +17,5 @@ def send_lines(server, target, msg, delay=0.7):
 
 
 
+
+
